[gold] Rename expectations.Baseline as expectations.BaselineInt.

Step 4 of the plan outlined in skbug.com/10522.

Bug: skia:10522
Change-Id: I80e373c9c980ed63a2452f2837a59d2fea13c67e
Reviewed-on: https://skia-review.googlesource.com/c/buildbot/+/304916
Commit-Queue: Leandro Lovisolo <lovisolo@google.com>
Reviewed-by: Kevin Lubick <kjlubick@google.com>
diff --git a/gold-client/go/goldclient/goldclient_test.go b/gold-client/go/goldclient/goldclient_test.go
index 76633c4..f235550 100644
--- a/gold-client/go/goldclient/goldclient_test.go
+++ b/gold-client/go/goldclient/goldclient_test.go
@@ -1527,7 +1527,7 @@
 			defer cleanup()
 
 			if label != unlabeled {
-				goldClient.resultState.Expectations = expectations.Baseline{
+				goldClient.resultState.Expectations = expectations.BaselineInt{
 					testName: {
 						digest: label,
 					},
@@ -1562,7 +1562,7 @@
 			defer cleanup()
 
 			if label != unlabeled {
-				goldClient.resultState.Expectations = expectations.Baseline{
+				goldClient.resultState.Expectations = expectations.BaselineInt{
 					testName: {
 						digest: label,
 					},
@@ -1605,7 +1605,7 @@
 				string(imgmatching.PixelDeltaThreshold): "0",
 			}
 
-			goldClient.resultState.Expectations = expectations.Baseline{
+			goldClient.resultState.Expectations = expectations.BaselineInt{
 				testName: {
 					digest: label,
 				},
@@ -1790,7 +1790,7 @@
 				string(imgmatching.PixelDeltaThreshold): "0",
 			}
 
-			goldClient.resultState.Expectations = expectations.Baseline{
+			goldClient.resultState.Expectations = expectations.BaselineInt{
 				testName: {
 					digest: label,
 				},
diff --git a/gold-client/go/goldclient/resultstate.go b/gold-client/go/goldclient/resultstate.go
index 30841b1..c9363ee 100644
--- a/gold-client/go/goldclient/resultstate.go
+++ b/gold-client/go/goldclient/resultstate.go
@@ -62,7 +62,7 @@
 	GoldURL         string
 	Bucket          string
 	KnownHashes     types.DigestSet
-	Expectations    expectations.Baseline
+	Expectations    expectations.BaselineInt
 }
 
 // newResultState creates a new instance of resultState
diff --git a/golden/go/baseline/simple_baseliner/simple_baseliner.go b/golden/go/baseline/simple_baseliner/simple_baseliner.go
index 4837dc4..ef56055 100644
--- a/golden/go/baseline/simple_baseliner/simple_baseliner.go
+++ b/golden/go/baseline/simple_baseliner/simple_baseliner.go
@@ -37,7 +37,7 @@
 		b := baseline.Baseline{
 			ChangeListID:     "",
 			CodeReviewSystem: "",
-			Expectations:     exp.AsBaseline(),
+			Expectations:     exp.AsBaselineInt(),
 		}
 		md5Sum, err := util.MD5Sum(b.Expectations)
 		if err != nil {
@@ -61,7 +61,7 @@
 		return &baseline.Baseline{
 			ChangeListID:     clID,
 			CodeReviewSystem: crs,
-			Expectations:     iexp.AsBaseline(),
+			Expectations:     iexp.AsBaselineInt(),
 			MD5:              md5Sum,
 		}, nil
 	}
@@ -76,7 +76,7 @@
 	b := baseline.Baseline{
 		ChangeListID:     clID,
 		CodeReviewSystem: crs,
-		Expectations:     exp.AsBaseline(),
+		Expectations:     exp.AsBaselineInt(),
 	}
 	md5Sum, err := util.MD5Sum(b.Expectations)
 	if err != nil {
diff --git a/golden/go/baseline/simple_baseliner/simple_baseliner_test.go b/golden/go/baseline/simple_baseliner/simple_baseliner_test.go
index f110a5a..23b1a41 100644
--- a/golden/go/baseline/simple_baseliner/simple_baseliner_test.go
+++ b/golden/go/baseline/simple_baseliner/simple_baseliner_test.go
@@ -32,7 +32,7 @@
 	assert.NoError(t, err)
 
 	exp := three_devices.MakeTestExpectations()
-	expectedBaseline := exp.AsBaseline()
+	expectedBaseline := exp.AsBaselineInt()
 
 	assert.Equal(t, expectedBaseline, b.Expectations)
 	assert.Equal(t, masterBranch, b.ChangeListID)
@@ -84,7 +84,7 @@
 	assert.Equal(t, crs, b.CodeReviewSystem)
 	// The expectation should be the master baseline merged in with the additionalTriages
 	// with additionalTriages overwriting existing expectations, if applicable.
-	assert.Equal(t, expectations.Baseline{
+	assert.Equal(t, expectations.BaselineInt{
 		"brand-new-test": {
 			IotaNewDigest:  expectations.PositiveInt,
 			KappaNewDigest: expectations.NegativeInt,
diff --git a/golden/go/baseline/types.go b/golden/go/baseline/types.go
index 7b60aaf..2f53963 100644
--- a/golden/go/baseline/types.go
+++ b/golden/go/baseline/types.go
@@ -15,7 +15,7 @@
 
 	// Expectations captures the "baseline expectations", that is, the Expectations with only the
 	// positive and negative digests (i.e. no untriaged digest) of the current commit.
-	Expectations expectations.Baseline `json:"master"`
+	Expectations expectations.BaselineInt `json:"master"`
 
 	// ChangeListID indicates the Gerrit or GitHub issue id of this baseline.
 	// "" indicates the master branch.
diff --git a/golden/go/expectations/expectations_test.go b/golden/go/expectations/expectations_test.go
index e6ba116..d630e50 100644
--- a/golden/go/expectations/expectations_test.go
+++ b/golden/go/expectations/expectations_test.go
@@ -202,7 +202,7 @@
 `, te.String())
 }
 
-func TestAsBaseline(t *testing.T) {
+func TestAsBaselineInt(t *testing.T) {
 	unittest.SmallTest(t)
 	input := Expectations{
 		labels: map[types.TestName]map[types.Digest]Label{
@@ -225,7 +225,7 @@
 		},
 	}
 
-	expectedOutput := Baseline{
+	expectedOutput := BaselineInt{
 		"beta": {
 			"hash1": PositiveInt,
 			"hash3": NegativeInt,
@@ -235,7 +235,7 @@
 			"hashA": NegativeInt,
 		},
 	}
-	require.Equal(t, expectedOutput, input.AsBaseline())
+	require.Equal(t, expectedOutput, input.AsBaselineInt())
 }
 
 // All this test data is valid, but arbitrary.
diff --git a/golden/go/testutils/data_three_devices/three_devices.go b/golden/go/testutils/data_three_devices/three_devices.go
index 60d6aa0..eac8109 100644
--- a/golden/go/testutils/data_three_devices/three_devices.go
+++ b/golden/go/testutils/data_three_devices/three_devices.go
@@ -66,7 +66,7 @@
 func MakeTestBaseline() *baseline.Baseline {
 	e := MakeTestExpectations()
 	b := baseline.Baseline{
-		Expectations:     e.AsBaseline(),
+		Expectations:     e.AsBaselineInt(),
 		ChangeListID:     "",
 		CodeReviewSystem: "",
 	}
diff --git a/golden/go/expectations/expectations.go b/golden/go/expectations/expectations.go
index 568730b..bf6b188 100644
--- a/golden/go/expectations/expectations.go
+++ b/golden/go/expectations/expectations.go
@@ -25,9 +25,9 @@
 	labels map[types.TestName]map[types.Digest]Label
 }
 
 // Baseline is a simplified view of the Expectations, suitable for JSON encoding. A Baseline only
 // has entries with positive and negative labels (i.e. no untriaged entries).
-type Baseline map[types.TestName]map[types.Digest]LabelInt
+type BaselineInt map[types.TestName]map[types.Digest]LabelInt
 
 // ReadOnly is an interface with the non-mutating functions of Expectations.
 // By using this instead of Expectations, we can make fewer copies, helping performance.
@@ -194,8 +194,8 @@
 	return s.String()
 }
 
-// AsBaseline returns a copy that has all untriaged digests removed.
-func (e *Expectations) AsBaseline() Baseline {
+// AsBaselineInt returns a copy that has all untriaged digests removed.
+func (e *Expectations) AsBaselineInt() BaselineInt {
 	e.mutex.RLock()
 	defer e.mutex.RUnlock()
 	n := Expectations{
@@ -209,10 +209,10 @@
 		}
 	}
 
-	// Convert the above into a Baseline.
-	// TODO(skbug.com/10522): Remove once expectations.LabelStr -> expectations.Label refactoring is
-	//                        done.
-	baseline := Baseline{}
+	// Convert the above into a BaselineInt.
+	// TODO(skbug.com/10522): Remove once the expectations.LabelStr -> expectations.Label refactoring
+	//                        is complete.
+	baseline := BaselineInt{}
 	for testName, digestToLabelStrMap := range n.labels {
 		digestToLabelMap := map[types.Digest]LabelInt{}
 		for digest, labelStr := range digestToLabelStrMap {
@@ -25,9 +25,9 @@
 }
 
-// Baseline is a simplified view of the Expectations, suitable for JSON encoding. A Baseline only
+// BaselineInt is a simplified view of the Expectations, suitable for JSON encoding. A BaselineInt only
 // has entries with positive and negative labels (i.e. no untriaged entries).